@@ -5,7 +5,7 @@ from fyle.platform import Platform
 
 from apps.workspaces.models import FyleCredential
 from .apis import Expenses, Employees, Categories, Projects, CostCenters, ExpenseCustomFields, CorporateCards, \
-    Reimbursements, TaxGroups, Merchants, Files
+    Reimbursements, TaxGroups, Merchants, Files, Departments
 
 logger = logging.getLogger(__name__)
 logger.level = logging.INFO
@@ -42,6 +42,7 @@ class PlatformConnector:
         self.tax_groups = TaxGroups()
         self.merchants = Merchants()
         self.files = Files()
+        self.departments = Departments()
 
         self.set_connection()
         self.set_workspace_id()
@@ -59,6 +60,7 @@ class PlatformConnector:
         self.tax_groups.set_connection(self.connection.v1beta.admin.tax_groups)
         self.merchants.set_connection(self.connection.v1beta.admin.expense_fields)
         self.files.set_connection(self.connection.v1beta.admin.files)
+        self.departments.set_connection(self.connection.v1beta.admin.departments)
 
     def set_workspace_id(self):
         """Set workspace ID for Fyle Platform APIs."""
@@ -73,6 +75,7 @@ class PlatformConnector:
         self.tax_groups.set_workspace_id(self.workspace_id)
         self.merchants.set_workspace_id(self.workspace_id)
         self.files.set_workspace_id(self.workspace_id)
+        self.departments.set_workspace_id(self.workspace_id)
 
     def import_fyle_dimensions(self, import_taxes: bool = False):
         """Import Fyle Platform dimension."""
